@@ -11,22 +11,34 @@ pub enum RpcRequest {
     DeregisterNode,
     GetAccountInfo,
     GetBalance,
+    GetBlock,
     GetBlockHeight,
     GetBlockProduction,
+    GetBlocks,
+    GetBlocksWithLimit,
     GetBlockTime,
     GetClusterNodes,
+
+    #[deprecated(since = "1.7.0", note = "Please use RpcRequest::GetBlock instead")]
     GetConfirmedBlock,
+    #[deprecated(since = "1.7.0", note = "Please use RpcRequest::GetBlocks instead")]
     GetConfirmedBlocks,
-    GetConfirmedBlocksWithLimit,
-
     #[deprecated(
-        since = "1.5.19",
-        note = "Please use RpcRequest::GetConfirmedSignaturesForAddress2 instead"
+        since = "1.7.0",
+        note = "Please use RpcRequest::GetBlocksWithLimit instead"
+    )]
+    GetConfirmedBlocksWithLimit,
+    #[deprecated(
+        since = "1.7.0",
+        note = "Please use RpcRequest::GetSignaturesForAddress instead"
     )]
-    GetConfirmedSignaturesForAddress,
-
     GetConfirmedSignaturesForAddress2,
+    #[deprecated(
+        since = "1.7.0",
+        note = "Please use RpcRequest::GetTransaction instead"
+    )]
     GetConfirmedTransaction,
+
     GetEpochInfo,
     GetEpochSchedule,
     GetFeeCalculatorForBlockhash,
@@ -49,6 +61,7 @@ pub enum RpcRequest {
     GetRecentBlockhash,
     GetRecentPerformanceSamples,
     GetSnapshotSlot,
+    GetSignaturesForAddress,
     GetSignatureStatuses,
     GetSlot,
     GetSlotLeader,
@@ -63,10 +76,7 @@ pub enum RpcRequest {
     GetTokenAccountsByDelegate,
     GetTokenAccountsByOwner,
     GetTokenSupply,
-
-    #[deprecated(since = "1.5.19", note = "Please use RpcRequest::GetSupply instead")]
-    GetTotalSupply,
-
+    GetTransaction,
     GetTransactionCount,
     GetVersion,
     GetVoteAccounts,
@@ -85,14 +95,16 @@ impl fmt::Display for RpcRequest {
             RpcRequest::DeregisterNode => "deregisterNode",
             RpcRequest::GetAccountInfo => "getAccountInfo",
             RpcRequest::GetBalance => "getBalance",
+            RpcRequest::GetBlock => "getBlock",
             RpcRequest::GetBlockHeight => "getBlockHeight",
             RpcRequest::GetBlockProduction => "getBlockProduction",
+            RpcRequest::GetBlocks => "getBlocks",
+            RpcRequest::GetBlocksWithLimit => "getBlocksWithLimit",
             RpcRequest::GetBlockTime => "getBlockTime",
             RpcRequest::GetClusterNodes => "getClusterNodes",
             RpcRequest::GetConfirmedBlock => "getConfirmedBlock",
             RpcRequest::GetConfirmedBlocks => "getConfirmedBlocks",
             RpcRequest::GetConfirmedBlocksWithLimit => "getConfirmedBlocksWithLimit",
-            RpcRequest::GetConfirmedSignaturesForAddress => "getConfirmedSignaturesForAddress",
             RpcRequest::GetConfirmedSignaturesForAddress2 => "getConfirmedSignaturesForAddress2",
             RpcRequest::GetConfirmedTransaction => "getConfirmedTransaction",
             RpcRequest::GetEpochInfo => "getEpochInfo",
@@ -117,6 +129,7 @@ impl fmt::Display for RpcRequest {
             RpcRequest::GetRecentBlockhash => "getRecentBlockhash",
             RpcRequest::GetRecentPerformanceSamples => "getRecentPerformanceSamples",
             RpcRequest::GetSnapshotSlot => "getSnapshotSlot",
+            RpcRequest::GetSignaturesForAddress => "getSignaturesForAddress",
             RpcRequest::GetSignatureStatuses => "getSignatureStatuses",
             RpcRequest::GetSlot => "getSlot",
             RpcRequest::GetSlotLeader => "getSlotLeader",
@@ -131,7 +144,7 @@ impl fmt::Display for RpcRequest {
             RpcRequest::GetTokenAccountsByDelegate => "getTokenAccountsByDelegate",
             RpcRequest::GetTokenAccountsByOwner => "getTokenAccountsByOwner",
             RpcRequest::GetTokenSupply => "getTokenSupply",
-            RpcRequest::GetTotalSupply => "getTotalSupply",
+            RpcRequest::GetTransaction => "getTransaction",
             RpcRequest::GetTransactionCount => "getTransactionCount",
             RpcRequest::GetVersion => "getVersion",
             RpcRequest::GetVoteAccounts => "getVoteAccounts",
